@@ -17,21 +17,26 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
 import sys
+from collections import Iterable
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse
+if sys.version_info[0] == 3:
+    base = (str, bytes)
+    coerce = str
+else:
+    base = basestring
+    coerce = unicode
+
+
+def is_list_like(value):
+    return isinstance(value, Iterable) and not isinstance(value, (base, dict))
+
+
+def is_str(string):
+    return isinstance(string, base)
 
 
 def to_str(string):
-    if sys.version_info[0] == 3:
-        base = (str, bytes)
-        coerce = str
-    else:
-        base = basestring
-        coerce = unicode
-    if not isinstance(string, base):
+    if not is_str(string):
         return coerce(string)
     return string
 
