@@ -50,7 +50,8 @@ class DateY(XY):
 
     def _todate(self, d):
         """ Converts a number to a date """
-        return str(self._offset + datetime.timedelta(seconds=d or 0))
+        currDateTime = self._offset + datetime.timedelta(seconds=d or 0)
+        return currDateTime.strftime( self.x_label_format )
 
     def _tonumber(self, d):
         """ Converts a date to a number """
