@@ -48,11 +48,8 @@ class XY(Line):
         """Check if there is any data"""
         return sum(
             map(len, map(lambda s: s.safe_values, self.series))) != 0 and any((
-                sum(map(abs, self.xvals)) != 0,
-                sum(map(abs, self.yvals)) != 0))
-
-    def _get_value(self, values, i):
-        return 'x=%s, y=%s' % tuple(map(self._format, values[i]))
+            sum(map(abs, self.xvals)) != 0,
+            sum(map(abs, self.yvals)) != 0))
 
     def _compute(self):
         if self.xvals:
@@ -65,6 +62,11 @@ class XY(Line):
         if self.yvals:
             ymin = min(self.yvals)
             ymax = max(self.yvals)
+
+            if self.include_x_axis:
+                ymin = min(ymin or 0, 0)
+                ymax = max(ymax or 0, 0)
+
             yrng = (ymax - ymin)
         else:
             yrng = None
@@ -75,8 +77,7 @@ class XY(Line):
                 vals = list(zip(*sorted(
                     filter(lambda t: None not in t,
                            serie.points), key=lambda x: x[0])))
-                serie.interpolated = self._interpolate(
-                    vals[1], vals[0], xy=True, xy_xmin=xmin, xy_rng=xrng)
+                serie.interpolated = self._interpolate(vals[0], vals[1])
 
         if self.interpolate and xrng:
             self.xvals = [val[0]
@@ -93,9 +94,9 @@ class XY(Line):
                 xrng = None
 
         if xrng:
-            self._box.xmin, self._box.xmax = min(self.xvals), max(self.xvals)
+            self._box.xmin, self._box.xmax = xmin, xmax
         if yrng:
-            self._box.ymin, self._box.ymax = min(self.yvals), max(self.yvals)
+            self._box.ymin, self._box.ymax = ymin, ymax
 
         x_pos = compute_scale(
             self._box.xmin, self._box.xmax, self.logarithmic, self.order_min)
