@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -32,7 +32,7 @@ class Serie(object):
 
     @cached_property
     def safe_values(self):
-        return filter(lambda x: x is not None, self.values)
+        return list(filter(lambda x: x is not None, self.values))
 
 
 class Label(object):
