@@ -20,6 +20,8 @@
 import pygal
 from pygal.util import cut
 from datetime import datetime
+from pygal.i18n import COUNTRIES
+COUNTRY_KEYS = list(COUNTRIES.keys())
 
 
 def get_data(i):
@@ -43,17 +45,27 @@ def pytest_generate_tests(metafunc):
             ])
 
 
-def make_data(chart, datas, secondary=False):
-    def get(data):
-        if isinstance(chart, pygal.XY):
-            if isinstance(chart, pygal.DateY):
-                # Convert to a credible datetime
-                return datetime.fromtimestamp(1360000000 + data * 987654)
-            return data
-        return cut(data)
+def adapt(chart, data):
+    if isinstance(chart, pygal.DateY):
+        # Convert to a credible datetime
+        return list(map(
+            lambda t:
+            (datetime.fromtimestamp(1360000000 + t[0] * 987654)
+             if t[0] is not None else None, t[1]), data))
 
-    for data in datas:
+    if isinstance(chart, pygal.XY):
+        return data
+
+    data = cut(data)
+    if isinstance(chart, pygal.Worldmap):
+        return list(map(lambda x: COUNTRY_KEYS[x % len(COUNTRIES)]
+                        if x is not None else None, data))
+    return data
+
+
+def make_data(chart, datas):
+    for i, data in enumerate(datas):
         chart.add(data[0],
-                  get(data[1]),
-                  secondary=secondary)
+                  adapt(chart, data[1]),
+                  secondary=bool(i % 2))
     return chart
