@@ -18,7 +18,7 @@
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
 from pygal import (
     Line, Dot, Pie, Radar, Config, Bar, Funnel, Worldmap,
-    SupranationalWorldmap, Histogram, Gauge)
+    SupranationalWorldmap, Histogram, Gauge, Box)
 from pygal._compat import u
 from pygal.test.utils import texts
 from pygal.test import pytest_generate_tests, make_data
@@ -210,6 +210,15 @@ def test_logarithmic_big_scale():
     assert len(q(".y.axis .guides")) == 41
 
 
+def test_value_formatter():
+    line = Line(value_formatter=lambda x: str(x) + u('‰'))
+    line.add('_', [10 ** 4, 10 ** 5, 23 * 10 ** 4])
+    q = line.render_pyquery()
+    assert len(q(".y.axis .guides")) == 11
+    assert q(".axis.y text").map(texts) == list(map(
+        lambda x: str(x) + u('‰'), map(float, range(20000, 240000, 20000))))
+
+
 def test_logarithmic_small_scale():
     line = Line(logarithmic=True)
     line.add('_', [1 + 10 ** 10, 3 + 10 ** 10, 2 + 10 ** 10])
@@ -261,7 +270,7 @@ def test_no_data():
 def test_include_x_axis(Chart):
     chart = Chart()
     if Chart in (Pie, Radar, Funnel, Dot, Gauge, Worldmap,
-                 SupranationalWorldmap, Histogram):
+                 SupranationalWorldmap, Histogram, Box):
         return
     if not chart.cls._dual:
         data = 100, 200, 150
